Below is a sample Bash script and accompanying guide that demonstrate one way to automate:

1. **Creating a single encrypted archive** from your data.  
2. **Splitting** that encrypted archive into 100GB chunks.  
3. **Generating checksums** and a manifest/catalog.  
4. **Optionally creating ISO images** from each chunk for more convenient burning.  
5. **Burning** the resulting chunks (or ISOs) to M-Disc.

> **Important**  
> - This script is written in Bash for Linux/macOS compatibility. It should also work on FreeBSD with minimal (if any) modifications, but you may need to install or adjust the relevant tools.  
> - The script focuses on automating the encryption and splitting steps, as well as generating a manifest.  
> - Burning to M-Disc on different platforms can vary. We show an example using `growisofs` (common on Linux) and `hdiutil` (macOS). Adjust as needed.  
> - For best security, do **not** hardcode your passphrase in the script. You should be prompted for it.

---

## How to Use the Script

1. **Install Dependencies**  
   Make sure the following tools are installed on your system(s):  
   - **tar**  
   - **xz**  
   - **gpg**  
   - **split**  
   - **sha256sum** (or `shasum` on FreeBSD/macOS)  
   - **genisoimage** or **mkisofs** (for creating ISOs if desired)  
   - **growisofs** (Linux) or **hdiutil** (macOS) for burning.

2. **Make the Script Executable**  
   ```bash
   chmod +x backup2mdisc.sh
   ```

3. **Run the Script**  
   ```bash
   ./backup2mdisc.sh /path/to/source /path/to/destination 100G --create-iso --burn
   ```
   - **`/path/to/source`**: The directory you want to back up.  
   - **`/path/to/destination`**: Where to store the intermediate backup files before burning.  
   - **`100G`**: The chunk size. Adjust if you're using different capacity discs.  
   - **`--create-iso`** (optional): Create ISO images from each chunk for more convenient burning.  
   - **`--burn`** (optional): Attempt to burn each chunk/ISO to disc automatically.

4. **Enter Your GPG Passphrase**  
   - The script will prompt for a passphrase. This passphrase encrypts your data. Keep it safe!

5. **Wait for the Script to Finish**  
   - A large `tar` + `xz` + `gpg` pipeline can take a considerable amount of time depending on your data size.  
   - After encryption, it splits into 100GB chunks.  
   - It then generates a **manifest** with SHA-256 checksums of each chunk.

6. **Burn to M-Disc**  
   - If you used `--burn`, the script will prompt you to insert an M-Disc for each chunk or ISO.  
   - On Linux, it uses `growisofs`. On macOS, it attempts `hdiutil` if ISO files exist.  
   - If you prefer manual burning, skip `--burn` and burn the `.iso` files using your favorite tool.

7. **Store the Manifest Safely**  
   - The manifest (`backup_manifest.txt`) in the work directory includes:  
     - Checksums for each chunk.  
     - The original source path.  
     - Timestamp.  
   - Keep this manifest (and the passphrase!) somewhere secure. You'll need all parts to restore.

---

## Restoring Your Backup

To **restore** from these discs:

1. Copy all chunk files (or `.iso` contents) back to a working directory on your system.  
2. Combine them back into a single file (if they were split outside of an ISO filesystem, just `cat` them together):  
   ```bash
   cat backup.tar.xz.gpg.* > backup.tar.xz.gpg
   ```
3. Decrypt and extract:  
   ```bash
   gpg --decrypt backup.tar.xz.gpg | xz -d | tar -xvf -
   ```
   You'll be prompted for the same GPG passphrase. Once it's done, the original files/folders should appear in your current directory.

---

### Notes & Tips

- **Individual Chunk Decryption**:  
  The above script creates **one** large encrypted archive, then splits it. You need **all** parts to decrypt. If you want each 100GB chunk to be decryptable separately, you'd need to tar smaller subsets of data individually, encrypt each, and then burn. This is more complex and requires advanced scripting or a specialized backup tool.

- **Automated Backup Tools**:  
  You might also consider tools like **Duplicati**, **Borg**, or **restic**, which support encryption, deduplication, and chunking. However, writing those chunks onto M-Disc is still a manual step.

- **Testing**:  
  Test with a small directory first (say 1GB) and 100MB “chunks” to ensure your workflow is correct. Then proceed to the full data.

- **M-Disc Drive Compatibility**:  
  Make sure your optical drive explicitly supports writing to 100GB BD-XL M-Disc. Standard Blu-ray or DVD drives often do not support higher-capacity M-Discs.

- **Verification**:  
  Always verify that your burned discs are readable. You can mount them and use the checksums from the manifest to confirm data integrity.

That's it! This script and guide should get you started creating encrypted backups on 100GB M-Discs, with a manifest to track chunks and checksums, plus optional ISO creation and automated burning steps. Adjust as necessary for your specific environment and needs.